@@ -29,7 +29,7 @@
 #include <KApplication>
 #include <KIcon>
 #include <KAboutData>
-#include <kdeversion.h>
+#include <config-workspace.h>
 
 #include <cassert>
 
@@ -39,7 +39,7 @@ int main(int argc, char *argv[])
         "oxygen-demo",
         "kstyle_config",
         ki18n( "Oxygen Demo" ),
-        KDE_VERSION_STRING,
+        WORKSPACE_VERSION_STRING,
         ki18n( "Oxygen style demonstration" ),
         KAboutData::License_GPL_V2,
         ki18n( "(c) 2010, Hugo Pereira Da Costa" ));
