@@ -37,8 +37,6 @@ public:
 
 public slots:
     virtual void save();
-    virtual void load();
-    virtual void defaults();
 
 private:
     Ui::ShowFpsEffectConfigForm *m_ui;
